/*
 * Copyright Bigeon Emmanuel (2014)
 *
 * emmanuel@bigeon.fr
 *
 * This software is a computer program whose purpose is to
 * provide a generic framework for console applications.
 *
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 *
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 */
/**
 * gclc:fr.bigeon.gclc.manager.EmptyInput.java
 * Created on: Nov 13, 2017
 */
package fr.bigeon.gclc.manager;

/** A console input that return empty to all prompting.
 *
 * @author Emmanuel Bigeon */
public final class EmptyInput implements ConsoleInput {

    /** The empty prompter. */
    public static final ConsoleInput INSTANCE = new EmptyInput();
    /** The empty input. */
    private EmptyInput() {
        //
    }
    /* (non-Javadoc)
     * @see fr.bigeon.gclc.manager.ConsoleInput#close() */
    @Override
    public void close() {
        //
    }

    /* (non-Javadoc)
     * @see fr.bigeon.gclc.manager.ConsoleInput#getPrompt() */
    @Override
    public String getPrompt() {
        return ""; //$NON-NLS-1$
    }

    /* (non-Javadoc)
     * @see fr.bigeon.gclc.manager.ConsoleInput#interruptPrompt() */
    @Override
    public void interruptPrompt() {
        //
    }

    /* (non-Javadoc)
     * @see fr.bigeon.gclc.manager.ConsoleInput#isClosed() */
    @Override
    public boolean isClosed() {
        return false;
    }

    /* (non-Javadoc)
     * @see fr.bigeon.gclc.manager.ConsoleInput#prompt() */
    @Override
    public String prompt() {
        return ""; //$NON-NLS-1$
    }

    /* (non-Javadoc)
     * @see fr.bigeon.gclc.manager.ConsoleInput#prompt(long) */
    @Override
    public String prompt(final long timeout) {
        return ""; //$NON-NLS-1$
    }

    /* (non-Javadoc)
     * @see fr.bigeon.gclc.manager.ConsoleInput#prompt(java.lang.String) */
    @Override
    public String prompt(final String message) {
        return ""; //$NON-NLS-1$
    }

    /* (non-Javadoc)
     * @see fr.bigeon.gclc.manager.ConsoleInput#prompt(java.lang.String,
     * long) */
    @Override
    public String prompt(final String message,
                         final long timeout) {
        return ""; //$NON-NLS-1$
    }

    /* (non-Javadoc)
     * @see fr.bigeon.gclc.manager.ConsoleInput#setPrompt(java.lang.String) */
    @Override
    public void setPrompt(final String prompt) {
        //
    }

}
